[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2018-10-04 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16639030#comment-16639030
 ] 

ASF GitHub Bot commented on CB-10180:
-

jcesarmobile closed pull request #65: CB-10180: (iOS) implement the 'quality' 
property in captureVideo()
URL: https://github.com/apache/cordova-plugin-media-capture/pull/65
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/README.md b/README.md
index 28580b0..5ba0961 100644
--- a/README.md
+++ b/README.md
@@ -372,6 +372,10 @@ capturing a video clip, the `CaptureErrorCB` callback 
executes with a
 ### iOS Quirks
 
 - The __limit__ property is ignored.  Only one video is recorded per 
invocation.
+- iOS supports an additional __quality__ property, to allow capturing video at 
different qualities.  A value of `1` means high quality and value of `0` ( the 
default ) means low quality, suitable for MMS messages.
+  See 
[here](https://developer.apple.com/reference/uikit/uiimagepickercontrollerqualitytype?language=objc)
 for more details.
+  A value of 0 corresponds to UIImagePickerControllerQualityTypeMedium (the 
default value of the 
[UIImagePickerController.videoQuality](https://developer.apple.com/reference/uikit/uiimagepickercontroller/1619154-videoquality?language=objc)
 property)
+  A value of 1 corresponds to UIImagePickerControllerQualityTypeHigh
 
 ### Android Quirks
 
diff --git a/src/ios/CDVCapture.m b/src/ios/CDVCapture.m
index 53e1b2b..53eb9e8 100644
--- a/src/ios/CDVCapture.m
+++ b/src/ios/CDVCapture.m
@@ -219,10 +219,11 @@ - (void)captureVideo:(CDVInvokedUrlCommand*)command
 options = [NSDictionary dictionary];
 }
 
 // options could contain limit, duration and mode
 // taking more than one video (limit) is only supported if provide own 
controls via cameraOverlayView property
 NSNumber* duration = [options objectForKey:@"duration"];
 NSString* mediaType = nil;
+NSNumber* quality = [options objectForKey:@"quality"];
 
 if ([UIImagePickerController 
isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera]) {
 // there is a camera, it is available, make sure it can do movies
@@ -263,7 +264,9 @@ - (void)captureVideo:(CDVInvokedUrlCommand*)command
 // iOS 4.0
 if ([pickerController 
respondsToSelector:@selector(cameraCaptureMode)]) {
 pickerController.cameraCaptureMode = 
UIImagePickerControllerCameraCaptureModeVideo;
-// pickerController.videoQuality = 
UIImagePickerControllerQualityTypeHigh;
+if (quality && [quality intValue] == 1) {
+pickerController.videoQuality = 
UIImagePickerControllerQualityTypeHigh;
+}
 // pickerController.cameraDevice = 
UIImagePickerControllerCameraDeviceRear;
 // pickerController.cameraFlashMode = 
@@ -219,10 +219,11 @@ - (void)captureVideo:(CDVInvokedUrlCommand*)command
 }
 
-// options could contain limit, duration and mode
+// options could contain duration, limit, mode and quality
 // taking more than one video (limit) is only supported if provide own 
controls via cameraOverlayView property
UIImagePickerControllerCameraFlashModeAuto;
 }


 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>Priority: Major
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2018-10-04 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16639029#comment-16639029
 ] 

ASF GitHub Bot commented on CB-10180:
-

jcesarmobile commented on issue #65: CB-10180: (iOS) implement the 'quality' 
property in captureVideo()
URL: 
https://github.com/apache/cordova-plugin-media-capture/pull/65#issuecomment-427200479
 
 
   Closing as on the discussion thread was decided to add this feature but with 
different values and the PR was not updated to reflect that.


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>Priority: Major
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2018-02-16 Thread Leander Smet (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16366787#comment-16366787
 ] 

Leander Smet commented on CB-10180:
---

[~maxpaj] Do you know when your pull request 'll be merged? Thanks!

> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>Priority: Major
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2017-06-06 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16038360#comment-16038360
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user darylldawn commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
@maxpaj works perfectly! thanks!


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.15#6346)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2017-06-06 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16038343#comment-16038343
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user maxpaj commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Check out my branch here: 
https://github.com/maxpaj/cordova-plugin-media-capture


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.15#6346)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2017-06-06 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16038299#comment-16038299
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user darylldawn commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Hi, is this already merged?


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: cordova-plugin-media-capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.15#6346)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2017-01-28 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15844230#comment-15844230
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user jcesarmobile commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
I started a discussion on the developer list about the quality

https://lists.apache.org/thread.html/e115b2a47b4e72e114825dedc5de8e55eaba76f7865f377907cf1df9@%3Cdev.cordova.apache.org%3E


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2017-01-28 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15844197#comment-15844197
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user maxpaj commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Any update on this? When will it be merged?


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-11-13 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15662669#comment-15662669
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user gkrizek commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
@rthomasclearwave I just cloned the repo and made the change myself


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-11-07 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15645132#comment-15645132
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user rthomasclearwave commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
I'm running into the same quality issue. Will this be updated?


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-11-04 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15638430#comment-15638430
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user junhui75165 commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
请问怎么默认调取前置摄像头


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-10-09 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15560073#comment-15560073
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user gkrizek commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Will this be merged? On iOS I can only record video in really low quality.


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-31 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15401527#comment-15401527
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user ryanwilliams83 commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Thanks for your feedback.
What if we went with 0=low, 1=medium, 2=high with a default of 1?
This is compatible with the Android implementation and still allows you to 
proof your code.
It doesn't change the quality on iOS (by default) and it has the same 
default value as the Android implementation.
I'm also willing to also support string values of 'low', 'medium' and 
'high', your thoughts?

I also had a thought of replacing the platform specific option of 'quality' 
with something like 'preferredWidth' (pixels) or 'preferredBitrate' so that it 
can be generic across platforms.


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-31 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15401367#comment-15401367
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user jcesarmobile commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
If you talk about the quality on the android implementation of the plugin, 
it only has the values 0 and 1 because the android component used only allows 
those two values 
https://developer.android.com/reference/android/provider/MediaStore.html#EXTRA_VIDEO_QUALITY

Anyway, this plugin shouldn't have quality parameter at all, it's supposed 
to follow the W3C API and it doesn't have quality option.



> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-31 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15401361#comment-15401361
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user nleclerc commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
If i may, i think that default behavior not being one of the explicit 
choices available is a bad idea.
It doesn't allow you to proof your code against default behavior changes.

I submitted another PR 
(https://github.com/apache/cordova-plugin-media-capture/pull/48) to implement 
video quality in iOS but the real problem is that whoever made the android 
quality change did quite a bad job at it.

If we don't want to end up with stupid options (like 0 low, 1 high and 2 
medium) we're gonna have to break compatibility.
Or Maybe we could use some String option values to have more verbose 
quality levels and keep the numeric ones to maintain compatibility.


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-30 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15400623#comment-15400623
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user jcesarmobile commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
If you do what I said you won't change the behavoiur, if there is no 
quality passed, then you use medium quality, that is how it works now. 
If you pass quality option with value 1 you use hight quality.
If you pass quality option with value 0 you use low quality.

If you don't do that then the changes on the README.md are not accurate, 
you say that 0 uses low quality, but you use medium quality, is medium quality 
suitable for MMS? I don't think so


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-28 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15398838#comment-15398838
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user ryanwilliams83 commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
UIImagePickerControllerQualityTypeMedium is the default value of the 
UIImagePickerController.videoQuality property and what is used in the current 
version of this plugin.

I didn't want to change the behavior of this plugin so I'm using Medium for 
0 and defaulting the value to 0.

Note the Android implementation of the quality property uses the default of 
1 which means High Quality


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-28 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15398066#comment-15398066
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user jcesarmobile commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Why do you use medium quality for value 0? shouldn't you use Low? 

I think you should use:
0 - low
1 - high
no quality passed - medium (default)


> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-27 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15395329#comment-15395329
 ] 

ASF GitHub Bot commented on CB-10180:
-

Github user cordova-qa commented on the issue:

https://github.com/apache/cordova-plugin-media-capture/pull/65
  
Cordova CI Build has completed successfully.

**Commit** - 
[Link](https://github.com/apache/cordova-plugin-media-capture/pull/65/commits/8ba8142ffdc591802cd42ffef675c3995537941c)
**Dashboard** - 
[Link](http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20/)

| Builder Name  | Console Output | Test Report | Device Logs  |
| :---: | :---:  |   :---: | :---:|
| [Windows 8.1 Store]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-store/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-store/console)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-store/testReport/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-store/artifact/)
 |
| [Windows 10  Store]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-10-store/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-10-store/console)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-10-store/testReport/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-10-store/artifact/)
 |
| [Windows 8.1 Phone]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-phone/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-phone/console)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-phone/testReport/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=windows-8.1-phone/artifact/)
 |
| [iOS]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=ios/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=ios/console)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=ios/testReport/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=ios/artifact/)
 |
| [Android]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=android/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=android/console)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=android/testReport/)
 | [Link]( 
http://cordova-ci.cloudapp.net:8080/job/cordova-plugin-media-capture-pr/20//PLATFORM=android/artifact/)
 |
 



> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-10180) Add support for video capture quality on iOS

2016-07-27 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-10180?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15395313#comment-15395313
 ] 

ASF GitHub Bot commented on CB-10180:
-

GitHub user ryanwilliams83 opened a pull request:

https://github.com/apache/cordova-plugin-media-capture/pull/65

CB-10180: (iOS) implement the 'quality' property in captureVideo()

### Platforms affected
iOS

### What does this PR do?
implement quality property for video capture.

### What testing has been done on this change?
captureVideo()
  'quality' omitted / 1 / 0

You can merge this pull request into a Git repository by running:

$ git pull https://github.com/buzzcard/cordova-plugin-media-capture quality

Alternatively you can review and apply these changes as the patch at:

https://github.com/apache/cordova-plugin-media-capture/pull/65.patch

To close this pull request, make a commit to your master/trunk branch
with (at least) the following in the commit message:

This closes #65


commit 8ba8142ffdc591802cd42ffef675c3995537941c
Author: Ryan Williams 
Date:   2016-07-27T08:59:14Z

CB-10180: (iOS) implement the 'quality' property in captureVideo()




> Add support for video capture quality on iOS
> 
>
> Key: CB-10180
> URL: https://issues.apache.org/jira/browse/CB-10180
> Project: Apache Cordova
>  Issue Type: Improvement
>  Components: Plugin Media Capture
>Affects Versions: 1.1.0
> Environment: iOS
>Reporter: Nicolas Leclerc
>  Labels: iOS, triaged
>
> iOS does not support the new {{quality}} option.
> Adding it would be great.
> I submitted a PR some time ago but rebased it to v1.1.0.
> https://github.com/apache/cordova-plugin-media-capture/pull/48



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org